@@ -1214,7 +1214,7 @@ class ContactService(BaseRdbmsService):
             connection=connection,
             property_name=contact.property_name)
 
-        existing_contact = [_ for _ in contacts if _.value == contact.property_value]
+        existing_contact = [_ for _ in contacts if _.property_value == contact.property_value]
         if len(existing_contact) == 0:
             if not add_if_not_exists:
                 raise self.UndefinedObjectException('This contact information is not associated to this user account')
@@ -1247,12 +1247,12 @@ class ContactService(BaseRdbmsService):
                 UPDATE 
                     account_contact
                   SET
-                    is_primary = (value = %(property_value)s),
+                    is_primary = (property_value = %(property_value)s),
                     update_time = current_timestamp
                   WHERE
                     account_id = %(account_id)s
                     AND property_name = %(property_name)s
-                    AND is_primary <> (value = %(property_value)s)
+                    AND is_primary <> (property_value = %(property_value)s)
                 """,
                 {
                     'account_id': account_id,
